@@ -29,11 +29,10 @@ query_data <- subset(ah, preparerclass == "excluderanges")
 query_data
 
 ## ----hg38excluderanges--------------------------------------------------------
-library(GenomeInfoDb)  # for keepStandardChromosomes()
 excludeGR.hg38.Kundaje.1 <- query_data[["AH107305"]]
 # Always a good idea to sort GRanges and keep standard chromosomes
 excludeGR.hg38.Kundaje.1 <- excludeGR.hg38.Kundaje.1 %>% 
-  sort() %>% keepStandardChromosomes(pruning.mode = "tidy")
+  sort() %>% GenomeInfoDb::keepStandardChromosomes(pruning.mode = "tidy")
 excludeGR.hg38.Kundaje.1
 
 ## ----eval=FALSE---------------------------------------------------------------
@@ -235,13 +234,13 @@ excludeGR.hg38.all <- reduce(c(excludeGR.hg38.Bernstein,
                                excludeGR.hg38.Yeo))
 # Sort and Keep only standard chromosomes
 excludeGR.hg38.all <- excludeGR.hg38.all %>% sort %>% 
-  keepStandardChromosomes(pruning.mode = "tidy")
+  GenomeInfoDb::keepStandardChromosomes(pruning.mode = "tidy")
 print(length(excludeGR.hg38.all))
 summary(width(excludeGR.hg38.all))
 
 ## -----------------------------------------------------------------------------
-query_data[grepl("mito", query_data$description, ignore.case = TRUE), ]
 hg38.Lareau.hg38_peaks <- query_data[["AH107343"]]
+hg38.Lareau.hg38_peaks
 
 ## ----eval=FALSE, echo=FALSE---------------------------------------------------
 # suppressMessages(library(httr))
@@ -295,6 +294,11 @@ query_data
 gapsGR_hg38_centromere <- query_data[["AH107354"]]
 gapsGR_hg38_centromere
 
+## -----------------------------------------------------------------------------
+query_data <- query(ah, c("excluderanges", "Mus musculus", "UCSC"))
+mm39.UCSC.centromere <- query_data[["AH107366"]]
+head(mm39.UCSC.centromere)
+
 ## ----eval=FALSE---------------------------------------------------------------
 # # hg38 CUT&RUN exclusion set, BED
 # download.file("https://drive.google.com/uc?export=download&id=1rKIu7kdiEySTi-cq3nYxXJP4VQX1IPcS",
@@ -315,8 +319,8 @@ gapsGR_hg38_centromere
 
 ## ----echo=FALSE---------------------------------------------------------------
 mtx <- read.csv("../man/figures/Table_S1.csv")
-# mtx$BEDbase.URL <- ifelse(!is.na(mtx$BEDbase.ID), paste0("[link](http://bedbase.org/#/bedsplash/", mtx$BEDbase.ID, ")"), "NA")
-knitr::kable(mtx[, c("Name", "Ahub.IDs.BioC.3.16.and.above", "Description", "Filtered.Region.count")]) # "BEDbase.URL", 
+mtx$BEDbase.URL <- ifelse(!is.na(mtx$BEDbase.ID), paste0("[link](http://bedbase.org/#/bedsplash/", mtx$BEDbase.ID, ")"), "NA")
+knitr::kable(mtx[, c("Name", "Ahub.IDs.BioC.3.16.and.above", "BEDbase.URL", "Description", "Filtered.Region.count")])
 
 ## ----'citation', eval = requireNamespace('excluderanges')---------------------
 print(citation("excluderanges"), bibtex = TRUE)
