@@ -1154,7 +1154,16 @@ meta <- data.frame(
             "dm6.UCSC.other",
             "dm3.UCSC.contig",
             "dm3.UCSC.scaffold",
-            "TAIR10.UCSC.araTha1.gap"),
+            "TAIR10.UCSC.araTha1.gap",
+            "hg38.GreyListChIP.STAR_36bp_1000merge",
+            "hg38.GreyListChIP.STAR_101bp_1000merge",
+            "T2T.GreyListChIP.STAR_36bp_1000merge",
+            "T2T.GreyListChIP.STAR_101bp_1000merge",
+            "mm10.GreyListChIP.STAR_36bp_1000merge",
+            "mm10.GreyListChIP.STAR_50bp_1000merge",
+            "mm39.GreyListChIP.STAR_36bp_1000merge",
+            "mm39.GreyListChIP.STAR_50bp_1000merge"
+  ),
   Description = c("Defined by the Boyle-Lab/Blacklist software, High Signal and Low Mappability regions",
                   "Defined as a combination of hg38.Lareau.hg38_peaks, hg38.Boyle.hg38-Excludable.v2, and hg38.Wimberley.peakPass60Perc_sorted, followed by manual curation. Supersedes hg38.Kundaje.GRCh38.Excludable.",
                   "Defined from Mint-ChIP (low input, multiplexed ChIP-seq) data",
@@ -1236,8 +1245,17 @@ meta <- data.frame(
                   "Sequence of Ns in the assembly that were not marked as gaps in the AGP (A Golden Path) assembly definition file",
                   "Gaps between contigs in scaffolds",
                   "Gaps between scaffolds in chromosome assemblies",
-                  "Gaps in the May 2011 Arabidopsis thaliana genome assembly"),
-  BiocVersion = rep("3.16", 82),
+                  "Gaps in the May 2011 Arabidopsis thaliana genome assembly",
+                  
+                  "GreyListChIP-generated exclusion set using STAR-aligned 36bp single-end reads (381 files combined), merging regions within 1,000bp",
+                  "GreyListChIP-generated exclusion set using STAR-aligned 100bp and 101bp paired-end reads (274 files combined), merging regions within 1,000bp",
+                  "GreyListChIP-generated exclusion set using STAR-aligned 36bp single-end reads (381 files combined), merging regions within 1,000bp",
+                  "GreyListChIP-generated exclusion set using STAR-aligned 101bp single-end reads (381 files combined), merging regions within 1,000bp",
+                  "GreyListChIP-generated exclusion set using STAR-aligned 36bp single-end reads (106 files combined), merging regions within 1,000bp",
+                  "GreyListChIP-generated exclusion set using STAR-aligned 50bp single-end reads (175 files combined), merging regions within 1,000bp",
+                  "GreyListChIP-generated exclusion set using STAR-aligned 36bp single-end reads (106 files combined), merging regions within 1,000bp",
+                  "GreyListChIP-generated exclusion set using STAR-aligned 50bp single-end reads (176 files combined), merging regions within 1,000bp"),
+  BiocVersion = c(rep("3.16", 82), rep("3.20", 8)),
   Genome = c("T2T-CHM13",
              "hg38",
              "hg38",
@@ -1319,10 +1337,19 @@ meta <- data.frame(
              "dm6",
              "dm3",
              "dm3",
-             "TAIR10"),
-  SourceType = rep("RDS", 82),
-  SourceUrl = rep("https://drive.google.com/drive/folders/1sF9m8Y3eZouTZ3IEEywjs2kfHOWFBSJT?usp=sharing", 82),
-  SourceVersion = rep("September 22 2022", 82),
+             "TAIR10",
+             
+             "hg38",
+             "hg38",
+             "T2T",
+             "T2T",
+             "mm10",
+             "mm10",
+             "mm39",
+             "mm39"),
+  SourceType = rep("RDS", 90),
+  SourceUrl = c(rep("https://drive.google.com/drive/folders/1sF9m8Y3eZouTZ3IEEywjs2kfHOWFBSJT?usp=sharing", 82), rep("https://drive.google.com/drive/folders/171xy6RypzjdrSfltbbEmDUKR6X7A-_NR?usp=sharing",8)),
+  SourceVersion = c(rep("September 22 2022", 82), rep("November 25 2024", 8)),
   Species = c("Homo sapiens",
               "Homo sapiens",
               "Homo sapiens",
@@ -1404,7 +1431,17 @@ meta <- data.frame(
               "Drosophila melanogaster",
               "Drosophila melanogaster",
               "Drosophila melanogaster",
-              "Arabidopsis thaliana"),
+              "Arabidopsis thaliana",
+              
+              "Homo sapiens",
+              "Homo sapiens", 
+              "Homo sapiens",
+              "Homo sapiens",
+              "Mus musculus",
+              "Mus musculus",
+              "Mus musculus",
+              "Mus musculus"
+  ),
   TaxonomyId = c("9606",
                  "9606",
                  "9606",
@@ -1486,7 +1523,16 @@ meta <- data.frame(
                  "7227",
                  "7227",
                  "7227",
-                 "3702"),
+                 "3702",
+                 
+                 "9606",
+                 "9606",
+                 "9606",
+                 "9606",
+                 "10090",
+                 "10090",
+                 "10090",
+                 "10090"),
   Coordinate_1_based = c(TRUE,
                          TRUE,
                          TRUE,
@@ -1568,6 +1614,15 @@ meta <- data.frame(
                          FALSE,
                          FALSE,
                          FALSE,
+                         TRUE,
+                         
+                         TRUE,
+                         TRUE,
+                         TRUE,
+                         TRUE,
+                         TRUE,
+                         TRUE,
+                         TRUE,
                          TRUE),
   DataProvider = c("excluderanges",
                    "ENCODE",
@@ -1650,10 +1705,19 @@ meta <- data.frame(
                    "UCSC",
                    "UCSC",
                    "UCSC",
-                   "UCSChub"),
-  Maintainer = rep("Mikhail Dozmorov <mikhail.dozmorov@gmail.com>", 82),
-  RDataClass = rep("GRanges", 82),
-  DispatchClass = rep("RDS", 82),
+                   "UCSChub",
+                   
+                   "GreyListChIP",
+                   "GreyListChIP",
+                   "GreyListChIP",
+                   "GreyListChIP",
+                   "GreyListChIP",
+                   "GreyListChIP",
+                   "GreyListChIP",
+                   "GreyListChIP"),
+  Maintainer = rep("Mikhail Dozmorov <mikhail.dozmorov@gmail.com>", 90),
+  RDataClass = rep("GRanges", 90),
+  DispatchClass = rep("RDS", 90),
   RDataPath = c("excluderanges/T2T.excluderanges.rds",
                 "excluderanges/hg38.Kundaje.GRCh38_unified_Excludable.rds",
                 "excluderanges/hg38.Bernstein.Mint_Excludable_GRCh38.rds",
@@ -1735,7 +1799,16 @@ meta <- data.frame(
                 "excluderanges/dm6.UCSC.other.rds",
                 "excluderanges/dm3.UCSC.contig.rds",
                 "excluderanges/dm3.UCSC.scaffold.rds",
-                "excluderanges/TAIR10.UCSC.araTha1.gap.rds"),
+                "excluderanges/TAIR10.UCSC.araTha1.gap.rds",
+                
+                "excluderanges/hg38.GreyListChIP.STAR_36bp_1000merge.rds",
+                "excluderanges/hg38.GreyListChIP.STAR_101bp_1000merge.rds",
+                "excluderanges/T2T.GreyListChIP.STAR_36bp_1000merge.rds",
+                "excluderanges/star_k101_1000_grey_T2T.rds",
+                "excluderanges/mm10.GreyListChIP.STAR_36bp_1000merge.rds",
+                "excluderanges/mm10.GreyListChIP.STAR_50bp_1000merge.rds",
+                "excluderanges/mm39.GreyListChIP.STAR_36bp_1000merge.rds",
+                "excluderanges/mm39.GreyListChIP.STAR_50bp_1000merge.rds"),
   Tags = c("T2T;excluderanges",
            "hg38;Kundaje;excluderanges",
            "hg38;Bernstein;excluderanges",
@@ -1817,7 +1890,16 @@ meta <- data.frame(
            "dm6;UCSC;other",
            "dm3;UCSC;contig",
            "dm3;UCSC;scaffold",
-           "TAIR10;UCSC;gap"),
+           "TAIR10;UCSC;gap",
+           
+           "hg38;GreyListChIP;STAR_36bp",
+           "hg38;GreyListChIP;STAR_101bp",
+           "T2T;GreyListChIP;STAR_36bp",
+           "T2T;GreyListChIP;STAR_101bp",
+           "mm10;GreyListChIP;STAR_36bp",
+           "mm10;GreyListChIP;STAR_50bp",
+           "mm39;GreyListChIP;STAR_36bp",
+           "mm39;GreyListChIP;STAR_50bp"),
   Notes = c("Original region counts: 2066; Filtered for standard chromosomes: 2066",
             "Original region counts: 910; Filtered for standard chromosomes: 910",
             "Original region counts: 12052; Filtered for standard chromosomes: 12052",
@@ -1899,6 +1981,14 @@ meta <- data.frame(
             "Original region counts: 572; Filtered for standard chromosomes: 268",
             "Original region counts: 37665; Filtered for standard chromosomes: 7",
             "Original region counts: 8; Filtered for standard chromosomes: 1",
-            "Original region counts: 357; Filtered for standard chromosomes: 357"))
+            "Original region counts: 357; Filtered for standard chromosomes: 357",
+            "Combined files: 381, merging regions within 1,000bp",
+            "Combined files: 274, merging regions within 1,000bp",
+            "Combined files: 381, merging regions within 1,000bp",
+            "Combined files: 381, merging regions within 1,000bp",
+            "Combined files: 106, merging regions within 1,000bp",
+            "Combined files: 175, merging regions within 1,000bp",
+            "Combined files: 106, merging regions within 1,000bp",
+            "Combined files: 176, merging regions within 1,000bp"))
 
 write.csv(meta, file="inst/extdata/metadata.csv", row.names=FALSE)
